summaryrefslogtreecommitdiff
path: root/include/m_clist.h
diff options
context:
space:
mode:
authorGeorge Hazan <ghazan@miranda.im>2019-03-27 18:53:07 +0300
committerGeorge Hazan <ghazan@miranda.im>2019-03-27 18:53:07 +0300
commitc5c5972135f392bd2ab5bacc6ce476e3aa267ca3 (patch)
tree7e286ac886d733e5a9273fa96f71d9ecd7436b0a /include/m_clist.h
parent33abe40382ca512cca7a21da2abfa685ce98d65c (diff)
Clist events:
- no need to save 4 bytes each time we wanna declare protocol-wide events; - all event adding code is forced to be executed in the main thread; - also fixes #1904 (ICQ: mail notification bug); - now we can use any event ids for global events.
Diffstat (limited to 'include/m_clist.h')
-rw-r--r--include/m_clist.h8
1 files changed, 3 insertions, 5 deletions
diff --git a/include/m_clist.h b/include/m_clist.h
index 116ddfa931..2739ae2a05 100644
--- a/include/m_clist.h
+++ b/include/m_clist.h
@@ -247,10 +247,8 @@ struct CLISTEVENT
MCONTACT hContact; // handle to the contact to put the icon by
DWORD flags; // ...of course
HICON hIcon; // icon to flash
- union {
- MEVENT hDbEvent; // caller defined but should be unique for hContact
- const char *lpszProtocol;
- };
+ MEVENT hDbEvent; // caller defined but should be unique for hContact
+ const char *moduleName; // for events with CLEF_PROTOCOLGLOBAL in flags
LPARAM lParam; // caller defined
const char *pszService; // name of the service to call on activation
MAllCStrings szTooltip; // short description of the event to display as a tooltip on the system tray
@@ -263,7 +261,7 @@ struct CLISTEVENT
#define CLEF_UNICODE 4 // set pszTooltip as unicode
#define CLEF_PROTOCOLGLOBAL 8 // set event globally for protocol, hContact has to be NULL,
// lpszProtocol the protocol ID name to be set
/////////////////////////////////////////////////////////////////////////////////////////
// gets the image list with all the useful icons in it
@@ -263,7 +261,7 @@ struct CLISTEVENT
#define CLEF_UNICODE 4 // set pszTooltip as unicode
#define CLEF_PROTOCOLGLOBAL 8 // set event globally for protocol, hContact has to be NULL,
- // lpszProtocol the protocol ID name to be set
+ // moduleName the protocol ID name to be set
/////////////////////////////////////////////////////////////////////////////////////////
// gets the image list with all the useful icons in it